@@ -18,7 +18,7 @@ from .base import (  # noqa: F401
     ExternalDependency, NotFoundDependency, ExternalLibrary, ExtraFrameworkDependency, InternalDependency,
     PkgConfigDependency, CMakeDependency, find_external_dependency, get_dep_identifier, packages, _packages_accept_language)
 from .dev import GMockDependency, GTestDependency, LLVMDependency, ValgrindDependency
-from .misc import (MPIDependency, OpenMPDependency, Python3Dependency, ThreadDependency, PcapDependency, CupsDependency, LibWmfDependency, LibGCryptDependency)
+from .misc import (CoarrayDependency, HDF5Dependency, MPIDependency, NetCDFDependency, OpenMPDependency, Python3Dependency, ThreadDependency, PcapDependency, CupsDependency, LibWmfDependency, LibGCryptDependency, GpgmeDependency, ShadercDependency)
 from .platform import AppleFrameworks
 from .ui import GLDependency, GnuStepDependency, Qt4Dependency, Qt5Dependency, SDL2Dependency, WxDependency, VulkanDependency
 
@@ -32,7 +32,10 @@ packages.update({
 
     # From misc:
     'boost': BoostDependency,
+    'coarray': CoarrayDependency,
     'mpi': MPIDependency,
+    'hdf5': HDF5Dependency,
+    'netcdf': NetCDFDependency,
     'openmp': OpenMPDependency,
     'python3': Python3Dependency,
     'threads': ThreadDependency,
@@ -40,6 +43,8 @@ packages.update({
     'cups': CupsDependency,
     'libwmf': LibWmfDependency,
     'libgcrypt': LibGCryptDependency,
+    'gpgme': GpgmeDependency,
+    'shaderc': ShadercDependency,
 
     # From platform:
     'appleframeworks': AppleFrameworks,
@@ -54,6 +59,8 @@ packages.update({
     'vulkan': VulkanDependency,
 })
 _packages_accept_language.update({
+    'hdf5',
     'mpi',
+    'netcdf',
     'openmp',
 })
